import React, { useCallback, useState } from 'react'
import { Button, Col, Space, Spin, Tooltip, } from 'antd'
import style from '../index.less'
import CreativeModal from "../../../components/creativeModal"
import { CreateAdProps } from '@/services/launchAdq/createAd'
import { BaseResult } from '@ahooksjs/use-request/lib/types'
import { ModalConfig } from '../ad'
import AdcreativeCol from "../adcreativeCol"
import CreativePup from './modal'

type Props = {
    queryForm: Partial<CreateAdProps>,
    setQueryForm: React.Dispatch<React.SetStateAction<Partial<CreateAdProps>>>,
    getSysAdgroups: BaseResult<any, any>,
    getSysAdcreative: BaseResult<any, any>,
    clearData: () => void,
}
function Creative(props: Props) {
    let { queryForm, getSysAdgroups, getSysAdcreative, setQueryForm, clearData } = props
    const [adModalConfig, setAdModalConfig] = useState<ModalConfig>({//新建广告弹窗
        visible: false,
        type: 'add'
    })
    const [creativeVisible, setCreativeVisible] = useState<boolean>(false) // 选择创意弹窗控制

    // 设置变量
    const handleAdModalConfig = useCallback((arg: ModalConfig) => {
        setAdModalConfig({ ...adModalConfig, ...arg })
    }, [adModalConfig])

    // 获取创意详情
    const getInfo = useCallback((sysAdcreativeId) => {
        getSysAdcreative.run(sysAdcreativeId).then(res => {
            setQueryForm({ ...queryForm, sysAdcreativeId, sysAdcreative: res });
            setCreativeVisible(false);
            clearData()
        })
    }, [queryForm])
    return <Col span={12} className={style.conRightBorder}>
        <div className={style.top}>创意基本信息
            {queryForm.sysAdcreative && <a onClick={() => {
                setQueryForm({ ...queryForm, sysAdcreative: undefined, sysAdcreativeId: undefined })
            }}>清空</a>}
        </div>
        <div className={style.center}>
            <Spin spinning={getSysAdcreative.loading}>
                <div className={style.centerContent}>
                    {(queryForm?.sysAdcreative && queryForm?.sysAdcreativeId) && <AdcreativeCol data={queryForm?.sysAdcreative} />}
                </div>
            </Spin>
        </div>
        <div className={style.bottom}>
            <Space size={20}>
                {queryForm?.sysAdgroup ? <>
                    <span onClick={() => { setCreativeVisible(true) }}>{queryForm?.sysAdcreative ? '重选创意' : '选择创意'}</span>
                </> : <Tooltip title="请先设置广告">
                    <span>选择创意</span>
                </Tooltip>}
                {queryForm?.sysAdgroup ? <>
                    <span onClick={() => { handleAdModalConfig(queryForm?.sysAdcreative ? { visible: true, type: 'edit' } : { visible: true, type: 'add' }) }}>{queryForm?.sysAdcreative ? '编辑创意' : '新建创意'}</span>
                </> : <Tooltip title="请先设置广告">
                    <span>新建创意</span>
                </Tooltip>}
            </Space>
        </div>
        {/* 选择创意 */}
        {creativeVisible && <CreativeModal siteSet={getSysAdgroups?.data?.siteSet} visible={creativeVisible} onClose={() => setCreativeVisible(false)} onChange={getInfo} sysAdcreativeId={queryForm?.sysAdcreativeId} promotedObjectType={queryForm.promotedObjectType as string} />}
        {/* 创建创意 */}
        {adModalConfig.visible && <CreativePup visible={adModalConfig.visible} type={adModalConfig.type} PupFn={handleAdModalConfig} callback={(values: any) => {
            setQueryForm({ ...queryForm, sysTargeting: values, }); setCreativeVisible(false); clearData();
            handleAdModalConfig({ visible: false, dataInfo: null, type: 'add' })
        }} dataInfo={queryForm.sysAdcreative} queryForm={queryForm} />}
    </Col>
}
export default Creative